geo_json/models/paint_props library

Classes

PaintProperties
A class that describes the basic properties of the Paint class, which can be passed to the "properties" field of the GeoJsonFeature and used to draw a specific feature